package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(C``````````0```````
M`*%P``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)B`````````F(``
M```````0``````$````&````````F]@```````"KV````````*O8````````
M!*`````````5`````````!```````@````8```````";^````````*OX````
M````J_@````````!H`````````&@``````````AD=.50````!````````)*,
M````````DHP```````"2C`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";V````````*O8````````J]@````````$
M*`````````0H``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````20````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````20```$T```!1````4@```%@```!9````6@````````!<````70``
M``````!>````7P```&$``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!AP```````````````!$@``````
M``````````````````````&H$@`````````````````````````````)$0``
M``````````````````````````'.$0````````````````````````````%*
M$@`````````````````````````````0$@``````````````````````````
M``&'$@`````````````````````````````8$@``````````````````````
M```````?$@````````````````````````````';$@``````````````````
M``````````&3$@`````````````````````````````H(```````````````
M``````````````+X(0````````````````````````````!`$@``````````
M``````````````````!&$@````````````````````````````+%$@``````
M``````````````````````*V$@````````````````````````````)@$@``
M``````````````````````````(!$@````````````````````````````!-
M$@````````````````````````````*5$@``````````````````````````
M``!4$@````````````````````````````!<$@``````````````````````
M``````)^$@````````````````````````````!D$@``````````````````
M``````````!J$@````````````````````````````!S(```````````````
M``````````````*O$@````````````````````````````"/$@``````````
M``````````````````"4$@````````````````````````````'L$0``````
M``````````````````````*<$@````````````````````````````(N$@``
M``````````````````````````";$@````````````````````````````(@
M$@````````````````````````````,\$@``````````````````````````
M``+W$0````````````````````````````)2$@``````````````````````
M``````+D$@````````````````````````````+Y$0``````````````````
M``````````"B$@````````````````````````````+<$@``````````````
M``````````````%8$@````````````````````````````"K(@``````````
M``````````````````"Z(`````````````````````````````#0$@``````
M``````````````````````*G$@````````````````````````````(^$@``
M``````````````````````````#5$@````````````````````````````#;
M(`````````````````````````````*)$@``````````````````````````
M``#U$@````````````````````````````%X$@``````````````````````
M``````#Z$@````````````````````````````)N$@``````````````````
M``````````%G$@````````````````````````````$`$@``````````````
M``````````````$1$@````````````````````````````'\$@``````````
M``````````````````!E$@````````````````````````````(-$@``````
M``````````````````````)'$@````````````````````````````+5$@``
M``````````````````````````$7$@````````````````````````````+-
M$@````````````````````````````$K$@``````````````````````````
M``'W$@````````````````````````````&V$@``````````````````````
M``````$R$@````````````````````````````+V(0``````````````````
M``````````%#$@````````````````````````````+Q$@``"0```````"`8
M`````````A0```'($@``"@```````%3X``````````(```-^$@``"0``````
M`#&(````````!D(```0J$@``"0```````#N0`````````&@```-;$@``"0``
M`````"N```````````8```/H$@``!P```````!AP``````````(```.A$@``
M"0```````#?0`````````[X```0.$@``"0```````"N(`````````=8```/9
M$```$P```````+!X``````````````-L$@``"0```````##8`````````*P`
M``.+$@``"0```````"G8`````````#P```.3$@``"0```````#`X````````
M`&X```.W$@``"0```````%(X`````````4X```/,$@``"0```````"U@````
M`````"(```0E$```$P```````,#8``````````````,A$@``"0```````")@
M`````````#P```/N$@``"0```````"V(`````````2(```/"$0``$@``````
M`+!P``````````@```0'$```$@```````+!X``````````````/>$@``"0``
M`````"(P``````````````/E$@``"0```````%'(`````````&P```,J$@``
M"0```````#"H`````````"P```-%$@``"0```````"IX`````````00```0;
M$@``"0```````%.(`````````18```/Z$@``"0```````"ZP`````````8(`
M;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`7U]D97)E
M9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED`'5N;&EN:P!M96UM;W9E
M`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA
M;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO
M;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!?7W-T86-K7V-H
M:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E
M<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F
M;&%G<P!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T
M:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I
M;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER
M;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM<S,Y,'@N<V\N,0!?<W1A<G1?8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT
M;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T
M80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````````````*^(````````
M``P````````@&````````*^@``````````P```````!4^````````*^X````
M``````P````````8<````````+````````````P```````"P`````````+`0
M``````````P```````!5&@```````+`8``````````P```````!5(```````
M`+`H``````````P```````!5(@```````+`P``````````P```````!5)@``
M`````+`X``````````P```````!5+@```````+!```````````P```````!5
MF@```````+!(``````````P```````!5-@```````+!8``````````P`````
M``!5.@```````+!@``````````P```````!50````````+!P``````````P`
M``````!7^@```````*^0````!`````H``````````````````*^8````!0``
M``H``````````````````*^H````#0````H``````````````````*^P````
M'`````H``````````````````*_`````(`````H``````````````````*_(
M````*0````H``````````````````*_0````+0````H`````````````````
M`*_8````+@````H``````````````````*_@````,P````H`````````````
M`````*_H````.`````H``````````````````*_P````.0````H`````````
M`````````*_X````/@````H``````````````````*VP`````@````L`````
M`````````````*VX`````P````L``````````````````*W`````!@````L`
M`````````````````*W(````!P````L``````````````````*W0````"```
M``L``````````````````*W8````"0````L``````````````````*W@````
M"@````L``````````````````*WH````"P````L``````````````````*WP
M````#`````L``````````````````*WX````#0````L`````````````````
M`*X`````#P````L``````````````````*X(````$`````L`````````````
M`````*X0````$0````L``````````````````*X8````$@````L`````````
M`````````*X@````$P````L``````````````````*XH````%`````L`````
M`````````````*XP````%0````L``````````````````*XX````%@````L`
M`````````````````*Y`````%P````L``````````````````*Y(````&```
M``L``````````````````*Y0````&0````L``````````````````*Y8````
M&@````L``````````````````*Y@````&P````L``````````````````*YH
M````'0````L``````````````````*YP````'@````L`````````````````
M`*YX````'P````L``````````````````*Z`````(0````L`````````````
M`````*Z(````(@````L``````````````````*Z0````(P````L`````````
M`````````*Z8````)`````L``````````````````*Z@````)0````L`````
M`````````````*ZH````)P````L``````````````````*ZP````*`````L`
M`````````````````*ZX````*@````L``````````````````*[`````*P``
M``L``````````````````*[(````+`````L``````````````````*[0````
M+0````L``````````````````*[8````+@````L``````````````````*[@
M````+P````L``````````````````*[H````,`````L`````````````````
M`*[P````,0````L``````````````````*[X````,@````L`````````````
M`````*\`````-`````L``````````````````*\(````-0````L`````````
M`````````*\0````-@````L``````````````````*\8````-P````L`````
M`````````````*\@````.@````L``````````````````*\H````.P````L`
M`````````````````*\P````/`````L``````````````````*\X````/0``
M``L``````````````````*]`````/P````L``````````````````*](````
M0`````L``````````````````*]0````00````L``````````````````*]8
M````0@````L``````````````````*]@````0P````L`````````````````
M`*]H````1`````L``````````````````*]P````10````L`````````````
M`````*]X````1@````L``````````````````*^`````2`````L`````````
M`.OO\'``)+D$``^G^_]@XP#P```DP.4```6NP.4``!X+Z^_Q$``$!_[C$/`X
M`"3`$```2GW2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!*?.,0$```!`?Q#1#C
M$!`,`!3`]/___^4`````P!```$IPXQ`0```$!_$-$.,0$`P`%,#T____U0``
M`!C`$```2F3C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!*6.,0$```
M!`?Q#1#C$!`,`!3`]/___[4```!(P!```$I,XQ`0```$!_$-$.,0$`P`%,#T
M____I0```&#`$```2D#C$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!*
M-.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```$HHXQ`0```$!_$-$.,0
M$`P`%,#T____=0```*C`$```2ASC$!````0'\0T0XQ`0#``4P/3___]E````
MP,`0``!*$.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```$H$XQ`0```$
M!_$-$.,0$`P`%,#T____10```/#`$```2?CC$!````0'\0T0XQ`0#``4P/3_
M__\U```!",`0``!)[.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$G@
MXQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```2=3C$!````0'\0T0XQ`0
M#``4P/3___\%```!4,`0``!)R.,0$```!`?Q#1#C$!`,`!3`]/___O4```%H
MP!```$F\XQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```2;#C$!````0'
M\0T0XQ`0#``4P/3___[5```!F,`0``!)I.,0$```!`?Q#1#C$!`,`!3`]/__
M_L4```&PP!```$F8XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```28SC
M$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!)@.,0$```!`?Q#1#C$!`,
M`!3`]/___I4```'XP!```$ETXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`
M$```26CC$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!)7.,0$```!`?Q
M#1#C$!`,`!3`]/___F4```)`P!```$E0XQ`0```$!_$-$.,0$`P`%,#T___^
M50```EC`$```243C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!)..,0
M$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```$DLXQ`0```$!_$-$.,0$`P`
M%,#T___^)0```J#`$```22#C$!````0'\0T0XQ`0#``4P/3___X5```"N,`0
M``!)%.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```$D(XQ`0```$!_$-
M$.,0$`P`%,#T___]]0```NC`$```2/SC$!````0'\0T0XQ`0#``4P/3___WE
M```#`,`0``!(\.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$CDXQ`0
M```$!_$-$.,0$`P`%,#T___]Q0```S#`$```2-CC$!````0'\0T0XQ`0#``4
MP/3___VU```#2,`0``!(S.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!``
M`$C`XQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```2+3C$!````0'\0T0
MXQ`0#``4P/3___V%```#D,`0``!(J.,0$```!`?Q#1#C$!`,`!3`]/___74`
M``.HP!```$B<XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```2)#C$!``
M``0'\0T0XQ`0#``4P/3___U5```#V,`0``!(A.,0$```!`?Q#1#C$!`,`!3`
M]/___44```/PP!```$AXXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```
M2&SC$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!(8.,0$```!`?Q#1#C
M$!`,`!3`]/___14```0XP!```$A4XQ`0```$!_$-$.,0$`P`%,#T___]!0``
M!%#`$```2$CC$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!(/.,0$```
M!`?Q#1#C$!`,`!3`]/___.4```2`P!```$@PXQ`0```$!_$-$.,0$`P`%,#T
M___\U0``!)C`$```2"3C$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!(
M&.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$@,XQ`0```$!_$-$.,0
M$`P`%,#T___\I0``!.#`$```2`#C$!````0'\0T0XQ`0#``4P/3___R5```$
M^,`0``!'].,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!```$?HXQ`0```$
M!_$-$.,0$`P`%,#T___\=0``!2C`$```1]SC$!````0'\0T0XQ`0#``4P/3_
M__QE```%0,`0``!'T.,0$```!`?Q#1#C$!`,`!3`]/___%4```58P!```$?$
MXQ`0```$!_$-$.,0$`P`%,#T___\10``!7#K;_`P`"3C\/](_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TP.7___YLQ$@``$?9Q"@``$?2N00`-,#E
M___]`<08``!'GI4`$`"G=``>P.7___W'Q"L``$@P["8`"`!\IRD``<#E___^
M?,#E___^V<08``!'FN,@$```%L#E____4)(`*CG$N```1X_C(+```!;`Y?__
M_T66`B2*XR"P```6P.7___\]6!#PM)8!)(KL(0`%`-BY%``BZR(``P`-P.7_
M__Z.X[#PJ``$XQ"P```$XQ`@```DP!```!M_XQ`@"``DQ!@``$>XXQ`@$``D
MP!```!MUXQ`@&``DP!```$?26$#PM+D$`%+$*P``1\WE3!````021!@4IR@`
M`;GRT!*G.0``ISL``:<6`%ZG2@`#N10`1.L4``,`#4$14`"G:0``Y4@0````
MP#````19Q"@``$>RP.7___SC&++L)@`*`'[$*```1ZC`Y?___AD8LL0H``!'
MH<#E___]@L`@```:)L#E```!I.PF`!\`?,`0``!'CN,0$````J=T``O`(```
M&>W`Y0```9/$*P``1X#`$```1WWC(!````*GA``%P.4```S9Q"@``$=VP.7_
M__[7P.7___N$N10`*^MO\.@`!`?^ZP,``P`-[",``P#8N00`8+D4`"+C!K``
M``3K(@`#``WC`E```"2G]/^-!P<'![D$`"_`,````!+C,#```!BG^_]@IPD`
M`.,`\```),#T````"0<'!P<``(F@!P<'!^MO\#``)$%`(`CC\/]8_W'$:```
M1ICE2/"@``#$6```1I[C,"`$`!3$*```1H#`Y?___17K;_#8``0'_@<'!P?`
M$```1NS`(```1NGL$@`*@&3$&```1G_L&``$`'P'\0?^!P<'!P<'P!```$;8
MP#```$;5N0D`,>L3``,`"NLS`#\`#+D(`#'K,P`!``KL.``-`'S$&```1G;L
M&``'`'S`(```1KP'\0?^!P<'!P<'ZY_P2``DP)```$:QX_#_8/]QE0"0`*=T
M`$O`$```1E/C$!````*GA``(Q"@``$9CP.7___S\P!```$11P+```$12P*``
M`$1+N0D`L<08``!&DNN[``,`"J>[___L&P`5H&6G&P`!Q!L``$:%ZQ$``P`-
MXQ&@```$#>'$&```1GOL&__Q0&7`Y?___X7`$```1@;C$!````*GA``(P"``
M`#?:P.7___L3D@&0`.N?\.@`!`?^!P<'!^OO\'``)./P_V#_<>OO\1``!`?^
M!P<'!\`0``!%_.,0$````J>$`!?K[_!P`"3`,```1DGC\/]@_W'`(```-Z_`
MY?___*CK[_$0``3`]/___UK`]/___U?K[_!P`"3C\/]@_W'K[_$0``0'_@<'
M!P?K;_`P`"3C\/]@_W'L*`!-`'S$&```1;_CH!````*GA`!$N00`8[D$`(*Y
M!`!"XQ!```"4[!8`+@!^&TBY!`!ZN10`E..P<````J>$`!VY!`!)N00`.+D$
M`"O`Y?__^T/L)@`?`'Y!&;``E3T0`*=T`!BYZ:"G0;FP`>NJ``,`"E"@8`"Y
M!``KZV_PT``$!_[L&/_5/7Y!0$`!I_3_RD%P<`BG]/_1I[D``*?T_^T'!^N_
M\%@`)./P_U#_<;)/`+!!,/"DZ[L`(``-LD\`L=('\*BP*,#E____EM4'\*BP
M**>$``7`Y?___5[KO_$(``0'_@<'!P<'!^N?\$@`)./P_U#_<;)/`*#KJ@`@
M``VR3P"AN00`LM('\*B@*$&0\*2Y!``YN00`*\#E____;.PF``L`?-4'\*B@
M**>$`![`Y?___3'C$/"D`!3$*```12/K$0`#``WC$"````CC(!`(``3C(!``
M`"3L*/_<`'Q!$!`(I_3_]>N?\/@`!`?^!P?K;_`P`"3C\/[(_W&R3P"0ZYD`
M(``-LD\`D=('\3"0*.PH`"<`?+D$`**5`"``IX0`(,#E___Y9[D$`'+L*``9
M`'Q!8/"@N00`)\#E___Z&[D$`++L)@`5`'RY!``GP.7___JQN00`*L#E___\
M'-4'\3"0**>$`&[`Y?___-1!L+`3P!```!=SIP@``+D$`"NR70`2IQ3__J>$
M_]?`$```%WNY!``KLET`$J<4__ZGA/_,N00`*J<9``"R7@`2IQ3__KD$`#NY
M"0`:IRD``+)>`".G%/_^N0D`*QH2IQH``KD4`"'`Y?__^A[`,```%U:Y!`""
MN00`6[D$`$K`Y?___%*Y!``VN00`*,#E___\"^PH`!G_?E@0\+BG*$``P!L`
M`/``[!(`#V!VN00`*,#E____:;D$`"C`Y?__^^2G]/^$N00`*,#E___YW:?T
M__3K;_%H``0'_NNO\%``)./P_LC_<;)/`+"Y!`"BZ[L`(``-03#PH+)/`+'2
M!_$PL"C`Y?__^A#L)@`I`'X8$J<X0`!8(/"XP"L``/``[",`"(!VI3^@`.PC
M``]@=J<Y``*Y!``JP.7___CV$!*G&O__B!``']4'\3"P*+D4`"&GA``)P.7_
M__PGIQ@``*?T__3KK_&(``0'_NMO\#``)./P_U#_<;)/`(#KB``@``VR3P"!
MN00`HM('\*B`*+D$`+.5/3``IW0`!$&P,`&G"```N00`&Z>9``!!,/"DLEX`
MD:<4__ZY!``JN0D`F\#E___^(NPH`"8`?*<(``"G&0``N00`,K)>`!.G%/_^
MN0D`$NR1`%\@9:<9``#C,;```)!",2``IQL``>PV__D`?-4'\*B`**>$`,?`
MY?__^\S$&```0\'CT!````2G&0``&'&G&P`!ZR$``P`-XR+?^/\"IW3_]^PG
M``(`V,`0``!$([D4`"+C$!```!+K(@`#``VGA`!]N00`,KD$`"W`Y?__^$+$
M&```0Y?C(!```"3L*/_(`'SL%P`!`-C$*```0XNY%``1XR`@```$ZQ$``P`-
M01$@`.5($````%!P\*2Y!``:XR`0``"4["@`!@!^["8`;CU^N0D`&NPI``(`
MV;D8`"'$>```0V?C8/"D`!3K9@`#``WC8'````C`Y?__^./C(&```"3L*/^,
M`'SC$/"D`!3C('````3K$0`#``WC$2````3C(*```)!"(!``0:"@`;D$`#'`
M*P```/]!$!`!IX0`!>PF__`]?I(],`"G*0``XS*P``"00C(0`*<K``'L-O_Y
M`'RG]/]<P!```$.;Y4P0```!P.7___BEN00`8NPH_T\`?+D4`$>Y!``]ZT0`
M`P`-P.7___BFQ!@``$,+XV`0```DI_3_=T$0$`&G]/^*ZV_PX``$!_X'!P<'
M!P?K[_!P`"3$&```0O'C\/]@_W'C(!```!;`Y?__^J3`4```-#7$2```0O;`
M,```%:GK[_$0``3`]/__^G4'!P<'ZV_P,``DX_#_6/]QQ+@``$+.XR"P```6
MP&```!;@P.7___J!P.7____.XR"P```6P.7___IXN00`5N5(\*```,!````&
MO,`P```5B<#E___WFNMO\-@`!`?^!P<'!P<'ZV_P,``DX_#_4/UQXQ#PJ`)Q
MLD\`@.N(`"``#;)/`('2!Q``@"C`Y?__][U!L/"FN00`4L!@```5;<!````5
M;*<Y$`&Y!``KP.7___=<["8`$/]^I[D``.,0\*@"<=4'$`"`**>$`$K`Y?__
M^GSL(!``(''L)/_P`'[CH/"G`7&G21``N00`.KD$`"O`Y?__^.JY!`"2["3_
MWP!^IRH``;D4`"+`Y?__]]ZY!`"R["C_TP!\N10`>>PJ``>@9;GH<!*Y84"A
M[+H`!\!EN>AP&KEA0+'LD!`!('*Y!`!'N00`.KD$`"O`Y?__^@U!%[``D@`0
M`*?T_[*Y!``KZV_PX`($!_X'!P<'P/3___]\!P?K;_`P`"3C\/[`_G'C$/$X
M`7&Y!`"RN00`<[)/`(#`(```%/CKB``@``VR3P"!T@<0`(`HP.7___R6ISD`
M+[D$`)*Y!``KP.7___@U["@`%@!\N00`.\`@```4X<#E___]WN,0\3@!<=4'
M$`"`**>$`*[`Y?__^>^G"```N00`&[D$`">GJ0``P#```!3/LEX`H:<4__[`
MY?__^7T;J[D$`%*GJ@`!07#Q.$'0\*CL6/_2`'R5`%``P!```!1PN>*`4>R8
M`!L`?*<(``"Y!``5N00`*;)=`!*G%/_^IW0`#L`P```4HZ<I``#`Y?__^5.Y
M!`!2I_3_W:<(``"G&0``N00`);)>`!*G%/_^&Q7L,?__`-BY!``EN1@`(Y4O
M(`"GA``A&AJG*`__[!+_E"!VX[#PH``DP&```!1YP$```!3CISD0`+D$`"?`
MY?__]E.G&!``IRH``>PA``K`=Z?T``&2`"``&!.G]/_3N00`/;D$`"?`Y?__
M^.[L)O^S`'Y8$/#`I2^``,`;``#P`.P2_ZE@=J<Y``&Y!``GP.7___8:[";_
MGP!^N00`-\`@```4-L#E___],[D$`"?`Y?__]RJY!`"RI_3_3KD$`"OK;_%P
M`00'_@<'N00`$N,P$```E.PV``0`?@?^01`0`:<^`"^YXH`AI_3_\P<'!P<'
M!^PH``D`?+D$`#*5`"``IW0`",`@```3P\#T___V_*<(``"G&0``LEX`$J<4
M__[C0!___W&YZ3`A[#0`!B!E[#8`!?]\IRD``:<G`!/L-``J8&25+S``IX3_
MWL`@```3YZ?T_]SC0$___W&G]/_OE2]``*>$__FYZ3`4IQL``;DA`#2G*0`!
MN>(P$J<7``2G]/_?XR!/__]QE2]``*=T`#:YZ3`4XR!/__]Q[#(`!B!E[#8`
M!?]\IQD``>-`3___<:<7`"BY"0!#IRD0`.P4``(`V>P2`"4@9>OO\'``)*=+
M``'C\/]@_W'L0!``(''`(```03'`Y?__]S[`(```02OK[_$0``0'_KD$`$*G
M]/^_E2]``*>$_].G]/_6IRD```?^!P<'!P<'Z[_P6``DP!```#'5X_#_,/]Q
MLD\`L.N[`"``#;)/`+'2!_#(L"C2(?"F$`K`(```$VO`Y?__^R?`(```$VK`
MY?__^R'`(```$VC`Y?__^QO`(```$V?`Y?__^Q7`(```$V7`Y?__^P_`(```
M$V?`Y?__^PG`(```$SG`Y?__^P/`(```$V'`Y?__^OW`(```$V#`Y?__^O?`
M(```$U_`Y?__^O'`(```$R;`Y?__^NO`(```$UC`Y?__^L'L*``+`'RY!``R
MP"```!-#P.7___P2P"```!-0P.7___JPN00`,NPH``D`?,`@```2Q<#E___\
M`<`@```32,#E___ZG[D$`#+L*``:`'S`(```$N[`Y?__^_#`,```$T[`(```
M$P7`Y?__^^?5!_#(L"BGA``FP.7___?[P"```!,NP.7___I]N00`,NPH``@`
M?,`@```2^J?T_]ZG20`*P#```!,E02#PM\#E___U@>PF_]4`?D$P\,&G]/_L
MZ[_Q*``$!_X'!P<'!P?$'0``/^BG'O__IW0`+NOO\'``),`@```2T^/P_V#_
M<<#E___Z2.PH`!P`?.,0(```D)4`(`"GA``4P!<````PN0,`$>P1/[\!5<0?
M```_P^OO\1``!,0L```_O0?^IQ@``*?T__3$+```/[4'_@<'Z^_P<``DX_#_
M8/]QP.7___>BP.7___7?["@`!@!\XR`@```$Z^_Q$``$!_X'!P<'ZV_P,``D
MN00`LN/P_V#_<<`@```2OL#E___Y_;D$`#OL*``)`'RY!`!BE0`@`*=T``O`
M(```$JWK;_#0``3`]/__^T7`Y?__]5[L)@`M`'RG"```N00`&[)>`"&G%/_^
MN00`-J<9``"R7@`3IQ3__KD)`!:Y"0`K02(0`L#E___TPL`P```2F+D$`*+`
M4```$B6Y!`!+P.7___;UN00`.J?T_\GK;_#0``0'_@<'!P?K;_`P`"3C\/X8
M]W'C$/'@"'&R3P!PZW<`(``-LD\`<=('$`!P*,`0```_+;D$`(+`(```$>_2
M#_"P$`C2!_#`$!C2+_#@$"#2#_#($%#2!_#8$&#`Y?__^8;L*``?`'RY!`"R
ME0`@`*>$`!C`Y?___W+C$/'@"''5!Q``<"BGA``%P.7___;GN00`*^MO\A@(
M!,#T___TO\#E____1+D$`++L)@`E`'Q!H/#(XR"@```"IW0`!\"P```2&Z?T
M`!C`Y?__^5#L)@`'`'RGJP`(I_3_[I4`(`"GA/_ZP.7___2:N00`LNPH__,`
M?*<(``"Y!``;IRD``+)>`"&G%/_^N0D`*^LB``$`#:<K``'`Y?__]"&Y!`!B
MN00`HN-`L```E.Q&`)L`?D&@\.#CL*````*GA``=N00`*\#E___Y$[D$`++L
M*`":`'R5`"``IX0`E<#E___Z&^PH`)``?KD$`"O`Y?__]%>Y!`"R0:#PL.RV
M``P`?..0H````J>$``:5`)``IW0`?J<(``"Y!``;IYD``+)>`)&G%/_^N00`
M)J<9``"R7@`2IQ3__KD)`!:Y"0";&I&GF@0$N10`F;D$`"G`Y?__\\?C8/"@
M`"2Y!`"BP#```!&7P&```!&1P%```!$EN00`2\#E___U]*<Y`<"Y!``JP.7_
M__6-["8`5?]^P.7___5W6&`@`.QH`$T1?L08```]^[D4`&:Y!`!:XT"````$
MP#```!%RXR`0```$P.7___3OI[D``.,0\>`(<=4'$`!P**=T_QVY!``KZV_R
M&`@$!_ZY!``JN10`1,`P```12L#E___UM4&PL`%!H*`"I_3_5*>K``BG]/]8
MN00`*<#E___Y@NPH``H`?KD$`"G`Y?__\[ZY!`"RIZL`"*?T_V=!,/$0N00`
M*L#E___SD1C2["@`%@!^Q!@``#VFN00`6N-`@```!,`P```1/>,@$```!,#E
M___TG*?T_ZU8$/$HIRA``,`;``#P`.P2_^9@=EBP\2S`Y?__];OLLO_>8'98
M$/$HIR@!P,`;```!_^P2_]1@=KD$`"G`Y?__\QFY!`"RP"```!$YP.7___@9
M["8`Q@!\XY"````$IP@``*<9``"Y!``ILEX`$J<4__ZY"0`9[!P`/@-^N10`
M(>,RG_S_<<`@```1'+)=`".G%/_^IW0`+^P8``T$?J<:__NY%``101&0`)4O
M$`"G=``BXQ"`"``"IX0`':<(``"G*0``N00`,;)>`".G%/_^N0D`(>PL``\#
M?>,R'_S_<<`@```0\K)=`".G%/_^N>*`D<#E___];NPF`-\`?KD$`"FG.0``
MP.7___,DN00`DAB"["@`T@!^ITD``J<Y_^Y!8/'@P.7___(UITD`!KD$`#:Y
M!``IP.7___0\E0#QX*=T`&.50_'AIW0`7Y5!\>*G=`!;E4/QXZ=T`%>52/'D
MIW0`4Y5%\>6G=`!/ITD``J<Y_\:Y!``IP.7___(+ITD`*;D$`#:Y!``IP.7_
M__02P!```!#[XQ#PH``DP%````_5N00`2L`P```0DKD$`"O`Y?__])^Y!``J
MP.7___1*N00`.\`@```/M,#E___XMKD$`"O`Y?___4VG]/[`XY"````$P.7_
M__*EN00`,KD$`"G`Y?__^I:Y!`"2[";_,0!\I_3_*Z=)``"G.0``N00`*<#E
M___QOL#E```-H[D4`(BY!`#2I4^``+D$`#:Y!``HP.7___.^["(`-`!^N00`
M*$&0\:-!@/&WP.7___.2N00`/;D$`"FY!`#8P.4```YAIVD`%.-`D```D+D$
M`"C`,```#]'`Y?__]#RGFP`!IXL``J=G__'`$```$'^2`/'?XQ#PH``DN00`
M;:?T_X"Y%`!"N00`-KD$`"W`Y0``#9&G]/^ZP#````^AP"````]FP.7___@Z
MP.7___%SP!```!!<N00`8N,0\*``),!0```/-+D$`$K`,```#_FY!``KP.7_
M__/^ISD!P+D$`"O`Y?__\Y?L)O]8_W[`Y?__\X%8$"``IQX`$:=T_T[`Y?__
M\4C`$```$#'C$/"H`"2GV@`!N10`';D$`&+C$/"@`"3`4```#P*Y!`!*P#``
M``_.N00`*\#E___SS*?T_\X'!P<'!P?K;_`P`"3C\/]@_W'$J```._+C(*``
M`!;`Y?__\ZBY!`"RXR"@```6P.7___.@T@`@N;"XP"````[IP.7___9O["@`
M"P!\E3$@`*=T``:5`"`!IX0`!<#E___[1<08```[RN,@$```%L#E___S@*=9
M``NG20`!P#````^/P.7___'F["8`40!\Q*@``#NTXR"@```6P.7___-JIUD`
M`Z=)``'`,```#WS`Y?__\="Y!`"R["8`O@!\Q)@``#N<XR"0```6P.7___-2
MIUD``Z=)``'`,```#W7`Y?__\;BY!`"R["@`\0!\P"````YTP.7___85N00`
MHNPH`,@`?.,@D```%L#E___S,N,0L!``!+D$`$KC,!````3`Y?__\;>G]`#2
MXQ`@$``$I[@``>-P$"@`!,2(```[7NR;__\`V%@@@`#&O0``.]2GI``5N18`
M(L#E___S"Z=9``"Y%`!)N00`-\#E___PHKD$`*+L)@`2`'S$'0``.[RG&O__
M[)'_A6!VI[@``<2H```[-*?T`$?$*```.Z^Y%``;ZQ$``P`-IS@$`.-A(```
M!.,0H```!%@@$`S`*P`@!`#L(P`28';C(!`0``2G"```LET`)J<4__ZG=/_0
MI[H``:?T_Z_C((```!;`Y?__\L&G60`"ITD``.,PH```!,#E___R]Z?T_^2Y
M%@`BI[H``<#E___RKKD$`#?`Y?__[WE8(*``QKT``#MFIT3_[Z?T_R_C(*``
M`!;`Y?__\IKC$+`0``3`0```#J[C,!````3`Y?__\1[C$+`0``3C$!````21
M0!`-IX3_*^,@H```%L#E___R?N,0L!``!.,P$```!,#E___P):?T_QK`Y?__
M^!"Y!`"BXR"0```6[*@`7P!\P.7___)EXQ"P$``$N00`2N,P$```!,#E___P
MZKD$`"K`Y?__\A7$N```.I;C(+```!;`Y?__\DRY!`"BXR"P```6P.7___)$
MITD``<`P```.7,#E___O/,!````.8;D$`#*Y!``JP.7___#"XR"P```6P.7_
M__(LD@`@N<`@```-5L#E___T_,0K```ZZ>PF`",`?,0H```ZW\#E___[0,0K
M```ZW>PF`!<`?,`@```..L#E___O3,#E___R"<0X```ZRN,0L!``!.-`,```
M!*?T_M.G.0'`Q"@``#K!P.7___&FN00`4NPH`!@1?NP2``$`V.P<`!(!?\08
M```ZK,1(```ZK>,P$```!,`@```.&\#E___O'.MO\-``!`?^!P?KK_!0`"3C
M\/]@_W&Y!`"RP.7___CTP.7___C=N00`HL#E___Z1.PH`!T`?NRX`!H`?)4`
ML`"GA``5P#````U<N00`*L#E___P`NRB``M@9+D$`"OKK_#P``3`]/__].?K
MK_#P``0'_K)/`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_<=('\R@0**>Y
M``!!$/"HN00`,>-+(#@`!.L$`"``#.,`,```),!*`````.-`,`@`)*>[``BG
M.P`0IU?_[:=)`$#C,!!H``3C,!!``(+C,!`0`(+C,!```(+L4R"_(57L4R`^
M`5;C4!"``"2G&P`(IT?_Z>.@\*@`!,*J6H)YF>.@("``".,P(```!.-`(!``
M!.,`(`@`!.,0(!@`!.,0\*``).RS(+\E5;GG$!3LLR`Z!5:Y@``0N0@`NN,0
M\*``@NN0``(`#+D(`+'LD``A'E;LV2"_`%6YY]"DN8``H[F"`*3L>R"_`%7C
M@/"P``3"BEJ">9GC@/"@``BY"`"*[*L[OR55Z[,``@`,[*<`.@56[+,`(1Y6
MN0@`J+F"`)NY@`"7N>?0&>R*(+\`5>QK(+\`5>.0\+@`!.-0\,``!,*:6H)Y
MF<):6H)YF;D(`)2Y"`"1[!H[OR55ZZ<``@`,[*<`(1Y6N8(`NKF``+BY@@"V
M['H@OP!5[!@`.@56N0@`U;D(`!FY"`#;[)$@OP!5Z[@``@`,XU#PR``$[+@`
M(1Y6PEI:@GF9N8(`J[D(`&6Y@`"IN8(`I[D(`*;LBR"_`%7L$3N_)57C4/#0
M``3L&0`Z!5;"6EJ">9FY"``=[-$@OP!5[!$[OR55[!T`.@56N0@`&NNI``(`
M#.RI`"$>5KF"`+JY@`"]N8(`N.QA(+\`5>R:(+\`5;D(`'7C4/#8``2Y"`![
MPEI:@GF9Z[T``@`,[+T`(1Y6N8(`J[F``*:Y@@"I[-L@OP!5N0@`A>P1.[\E
M5;D(`(KL%@`Z!5;KI@`"``RY"``7[*8`(1Y6['$@OP!5N8(`NN-0\.``!+F`
M`+?"6EJ">9FY@@"][&H@OP!5N0@`E>P1.[\E5;D(`)OL%P`Z!5;KMP`"``RY
M"``8[+<`(1Y6[($@OP!5N8(`J^-0\.@`!+F``*C"6EJ">9FY@@"F['L@OP!5
MN0@`U>P1.[\E5;D(`-KL&``Z!5;KJ``"``RY"``9[*@`(1Y6[)$@OP!5N8(`
MNN-0\/``!+F``+G"6EJ">9FY@@"W[(H@OP!5N0@`9>P1.[\E5;D(`&OL&0`Z
M!5;KN0`"``RY"``=[+D`(1Y6[-$@OP!5N8(`J^-0\/@`!+F``*W"6EJ">9FY
M@@"H[)L@OP!5N0@`=>P1.[\E5;D(`'KL'0`Z!5;KK0`"``RY"``6[*T`(1Y6
M[&$@OP!5N8(`NN-0\0``!+F``+;"6EJ">9FY@@"Y[-H@OP!5N0@`A>P1.[\E
M5;D(`(OL%@`Z!5;KM@`"``RY"``7[+8`(1Y6['$@OP!5N8(`J^-0\0@`!+F`
M`*?"6EJ">9FY@@"M[&L@OP!5N0@`E>P1.[\E5;D(`)KL%P`Z!5;KIP`"``RY
M"``8[*<`(1Y6[($@OP!5N8(`NN-0\1``!+F``+C"6EJ">9FY@@"V['H@OP!5
MN0@`U>P1.[\E5;D(`-OL&``Z!5;KN``"``RY"``9[+@`(1Y6[)$@OP!5N8(`
MJ^-0\1@`!+F``*G"6EJ">9FY@@"G[(L@OP!5N0@`9>P1.[\E5;D(`&KL&0`Z
M!5;KJ0`"``RY"``=[*D`(1Y6[-$@OP!5N8(`NN-0\2``!+F``+W"6EJ">9FY
M@@"X[)H@OP!5N0@`=>P1.[\E5;D(`'OL'0`Z!5;KO0`"``RY"``6[+T`(1Y6
M[&$@OP!5N8(`J^-0\2@`!+F``*;"6EJ">9FY@@"I[-L@OP!5N0@`A>P1.[\E
M5;D(`(KL%@`Z!5;KI@`"``RY"``7[*8`(1Y6['$@OP!5N8(`NN-0\3``!+F`
M`+?"6EJ">9FY@@"][&H@OP!5N0@`E>P1.[\E5;D(`)OL%P`Z!5;KMP`"``RY
M"``8[+<`(1Y6[($@OP!5N8(`J^P1.[\E5;F``*CL&``Z!5:Y@@"FN0@`&>-0
M\3@`!,):6H)YF;D(`-6Y"`"M[)$@OP!5['L@OP!5[-$[OR55[-$@.@56XQ#Q
M0``$N0@`VL(:6H)YF>NH``(`#+D(`&'LJ``A'E:Y@@"ZN8``N;F"`+>Y"`"V
MXQ#Q2``$[&T[OR55PAINV>NA[&T@.@56N0@`%[D(`&OKN0`"``SLN0`A'E:Y
MY[":N8(`G;D:`!GL=CN_)57LG2*_/E7L=B`Z!5;LG0(A'E:Y"`!QN>>0B^,0
M\5``!+F"`(;"&F[9ZZ&Y&@`:N1H`&.R&(K\^5;D$`*'LA@(A'E;L%SN_)57L
M%R`Z!5:Y"``:XZ#Q6``$PJINV>NAN>>`:;D:`*NY@@!GN00`NKD:`+;LH3N_
M)57L9R*_/E7LH2`Z!5;L9P(A'E:Y"`"KN>=@>..P\6``!+F"`''"NF[9ZZ&Y
M&@"YN1H`M[D$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#Q:``$
MN>>0=L(:;MGKH;F"`'JY&@`8N1H`%[D$`('L&SN_)57L&R`Z!5:Y"``8[(HB
MOSY5[(H"(1Y6XZ#Q<``$PJINV>NAN1H`IKGG@&FY@@!KN1H`IKD$`'KLH3N_
M)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#Q>``$N>=P:,*Z;MGKH;F"`&&Y
M&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#Q@``$
MN>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L&SN_)57L&R`Z!5:Y"``8[(HB
MOSY5[(H"(1Y6XZ#QB``$N>>`:<*J;MGKH;F"`&NY&@"GN1H`IKD$`'KLH3N_
M)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#QD``$N>=P:,*Z;MGKH;F"`&&Y
M&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#QF``$
MN>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L&SN_)57L&R`Z!5:Y"``8[(HB
MOSY5[(H"(1Y6XZ#QH``$N>>`:<*J;MGKH;F"`&NY&@"GN1H`IKD$`'KLH3N_
M)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#QJ``$N>=P:,*Z;MGKH;F"`&&Y
M&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#QL``$
MN>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L&SN_)57L&R`Z!5:Y"``8[(HB
MOSY5[(H"(1Y6XZ#QN``$N>>`:<*J;MGKH;F"`&NY&@"GN1H`IKD$`'KLH3N_
M)57LH2`Z!5:Y"`"G['LBOSY5['L"(1Y6X[#QP``$N>=P:,*Z;MGKH;F"`&&Y
M&@"YN1H`MKD$`)OLNCN_)57LNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#QR``$
MN>>09\(:;MGKH;F"`&JY&@`8N1H`%KD$`('L:B*_/E7L&SN_)57L:@(A'E;L
M&R`Z!5;CH/'0``2Y"``8PJINV>NAN1H`I[GG8'FY@@![N1H`I[D$`(KCT/'8
M``3LH3N_)57"VF[9ZZ'LH2`Z!5:Y&@#9N0@`J.R+(K\^5>R+`B$>5KD$`+VY
MYX"6N8(`D;D:`+GL>B"_`%7LVCN_)57LUP`Z!5:Y"`#;[+$BOSY5[+$"(1Y6
MXQ#QX``$PAINV>NAN1H`%K/!``&YY[`8N8(`&K/-`*#LG2"_`%7LW3N_)57L
MV0`Z!5:Y&@"AZQ<``@`,N0@`K>P7`"$>5NQQ(+\`5;GF$-NYY'!;N8``V;F!
M`-7L:B"_`%7C4/'H``3"6H\;O-RY&@!8N>A0C>S:.[\E5>NI``(`#.RI`"$>
M5KF!`!JY@``6N>1PFKF!`)'C$/'P``3"&H\;O-RY&@`;N0@`&>S6`#H%5KD(
M`-CLC2"_`%7LO3N_)57LN``Z!5:Y"`"QZQ8``@`,[!8`(1Y6[&$@OP!5N>1@
M6KGF$-JY@`#8N8$`U>-0\?@`!,):CQN\W+D(`'7LFR"_`%6Y"`#7['L[OR55
MZ[@``@`,[+@`(1Y6N8$`&[F``!FYY&"+N8$`@>,0\@``!,(:CQN\W+D:`!JY
M"``8['D`.@56N0@`?>S7(+\`5>RG.[\E5>RM`#H%5KD(`*'K&0`"``SL&0`A
M'E;LD2"_`%6YY)!;N>80>[F``'VY@0!UXU#R"``$PEJ/&[S<N0@`9>R*(+\`
M5;D(`';L:CN_)57KK0`"``SL:``Z!5;LK0`A'E:Y"`!GN8$`&KF``!CL=B"_
M`%6YY)#:N8$`T>,0\A``!,(:CQN\W+D:`!OLMCN_)56Y"``=[+<`.@56N0@`
ML>QK(+\`5>L8``(`#.P8`"$>5NR!(+\`5;GD@%JYYA#:N8``U[F!`-7C4/(8
M``3"6H\;O-RY"`"5N0@`V>R;.[\E5>NW``(`#.RW`"$>5KF!`!NY@``6N>2`
M>[F!`''C$/(@``3"&H\;O-RY&@`:N0@`%^R6`#H%5KD(`)WLV2"_`%7LJ3N_
M)57LK0`Z!5:Y"`"AZQ8``@`,[!8`(1Y6['$@OP!5N>1P6[GF$&NY@`!MN8$`
M9>-0\B@`!,):CQN\W+D(`(7LFB"_`%6Y"`!H[(H[OR55ZZT``@`,[*T`(1Y6
MN8$`&KF``!FYY'#:N8$`T>,0\C``!,(:CQN\W+D:`!NY"``=[(D`.@56N0@`
MANQH(+\`5>RX.[\E5>RV`#H%5KD(`+'K&0`"``SL&0`A'E;LD2"_`%6YY)!:
MN>80VKF``-:Y@0#5XU#R.``$PEJ/&[S<N0@`=>R+(+\`5;D(`-?L>SN_)57K
MM@`"``SLM@`A'E:Y@0`;N8``&+GDD&NY@0!AXQ#R0``$PAJ/&[S<N1H`&KD(
M`!;L>``Z!5:Y"`!][-<@OP!5[*<[OR55[*T`.@56N0@`H>L8``(`#.P8`"$>
M5NR!(+\`5;GD@%NYYA!KN8``;;F!`&7C4/)(``3"6H\;O-RY"`"5['H@OP!5
MN0@`:>R:.[\E5>NM``(`#.RM`"$>5KF!`!JY@``7N>2`VKF!`-'C$/)0``3"
M&H\;O-RY&@`;N0@`'>R7`#H%5KD(`);L:2"_`%7LN3N_)57LM@`Z!5:Y"`"Q
MZQ<``@`,[!<`(1Y6['$@OP!5N>80VKGD<%JY@`#6N8$`U>-0\E@`!,):CQN\
MW+D(`(6Y"`"-Z]8``@`,[-8`(1Y6N>;08;GD<!WLFR"_`%7LNSN_)56Y@`!I
M[+D`.@56N8$`8;D(`+CC$/)@``3"&H\;O-RY&@`:N0@`8>R+(+\`5>P;.[\E
M5>NY``(`#.P8`#H%5NRY`"$>5KD(`!;LFR"_`%6YYK!MN>207;F``&BY@0!E
MXU#R:``$PEJ/&[S<N0@`=;D(`';K:``"``SL:``A'E:YYF"+N>20MNRA(+\`
M5>P1.[\E5;F``(KL&@`Z!5:Y@0"+N0@`%^.P\G``!,*ZCQN\W+D:`+WL<2"_
M`%6Y"`"+[+$[OR55ZQH``@`,[!H`(1Y6[*$@OP!5N>2@5KGF$-;LMP`Z!5:Y
M@`#7N0@`N+F!`-7C4/)X``3"6H\;O-RY"`"5N0@`V>R+(+\`5>R;.[\E5>R;
M(#H%5KD(`)WKUP`"``SLUP`A'E:YY*"]N8$`';F``!BY@0`;X[#R@``$PKJ/
M&[S<N1H`MKD(`+'K>``"``SL&3N_)57L>``A'E;L&2`Z!5:YYW"-N0@`&[F"
M`(GCL/*(``3"NLIBP=:Y"`"ZN1H`N.RA.[\E5>R)(K\^5>RA(#H%5NR)`B$>
M5KD(`*NYYX!GX[#RD``$N8(`8<*ZRF+!UKD:`+VY&@"VN00`F^QA(K\^5>RZ
M.[\E5>QA`B$>5NRZ(#H%5KD(`+GCD/*8``3"FLIBP=:Y&@"7N>=@>+D$`!FY
M@@!ZN1H`%^R;.[\E5>QZ(K\^5>R;(#H%5NQZ`B$>5KD(`)'C$/*@``3"&LIB
MP=:Y&@`8N>=PAKF"`(NY&@`8N00`H>R+(K\^5>P9.[\E5>R+`B$>5NP9(#H%
M5N.P\J@`!+D(`!K"NLIBP=:Y&@"VN>>`9[F"`&FY&@"VN00`J^QI(K\^5>RQ
M.[\E5>QI`B$>5NRQ(#H%5KD(`+KCH/*P``3"JLIBP=:Y&@"GN>=@>+F"`'&Y
M&@"GN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/*X``2YYY!V
MPAK*8L'6N8(`>[D:`!BY&@`7N00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7L
MBP(A'E;CL/+```3"NLIBP=:Y&@"VN>>`:;F"`&JY&@"VN00`>^RQ.[\E5>RQ
M(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/+(``3"JLIBP=:Y&@"IN>=P:+F"`&&Y
M&@"FN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/+0``2YYY!G
MPAK*8L'6N8(`:[D:`!BY&@`6N00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7L
MBP(A'E;CL/+8``2YYX!IPKK*8L'6N8(`:KD:`+>Y&@"VN00`>^RQ.[\E5>RQ
M(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/+@``2YYW!HPJK*8L'6N8(`8;D:`*FY
M&@"FN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/+H``2YYY!G
MPAK*8L'6N8(`:[D:`!BY&@`6N00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7L
MBP(A'E;CL/+P``2YYX!IPKK*8L'6N8(`:KD:`+>Y&@"VN00`>^RQ.[\E5>RQ
M(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/+X``2YYW!HPJK*8L'6N8(`8;D:`*FY
M&@"FN00`FNRK.[\E5>RK(#H%5KD(`*GLD2*_/E7LD0(A'E;C$/,```2YYY!G
MPAK*8L'6N8(`:[D:`!BY&@`6N00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7L
MBP(A'E;CL/,(``2YYX!IPKK*8L'6N8(`:KD:`+>Y&@"VN00`>^RQ.[\E5>RQ
M(#H%5KD(`+?L>B*_/E7L>@(A'E;CH/,0``3"JLIBP=:Y&@"IN>=PF+F"`)&Y
M&@"I[)L[OR55[)L@.@56N0@`FNRA(K\^5>RA`B$>5N,0\Q@`!+GGH-?"&LIB
MP=:Y@@#;N1H`&+D:`!VY!`"![&D@OP!5[!D[OR55[!8`.@56N0@`&.R+(K\^
M5>R+`B$>5N.P\R``!,*ZRF+!UNS1(+\`5;D(`#OL$3N_)56YYX"Z[!T`.@56
MN1H`-[F"`)NY&@`YN0@`$\`:`````.,0(```)..@("``"+D(`-#C@/"@``C`
MV@````#CT"`(`"3`B@````#C@"`8`"3`J@````#CH"`@`"3K%@`"``SL%@`A
M'E:Y"`!!P$H`````XT`@$``DLD\`$.L1`"``#;)/`!'5!_,H$"BGA``%P.7_
M_^</ZV_S8``$!_[K[_!P`"2G*0"`X_#_8/]QP.7__^2`P#%G12,!XS`@```D
MP#_OS:N)XS`@"``DP#^8NMS^XS`@$``DP#$0,E1VY4@@*```XS`@&``DY4@@
M,```P#_#TN'PY4P@>```XS`@(``DZ^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-
MN00`HKD$`+3C("`H``2Y"``2[$$@OP!5X_#_8/]QN3$`(:?$``7K`:`P`'KC
M0*`H`"3K&P`=``SC$*`P``CC$*`P`"1!D*`XXQ"@>``2IX0`,:>(`$`;@1F+
MN00`*;GRL(NY&``AN10`2.PC``>@9;GH0!*Y84`QN>A`<^PC``7`9;EA0"?`
MY?__YE<8&%H0H'A0$*!X[!8`,D!^N00`*ANXN10`N\#E___TA[D$`#?KBP`&
M`-ZGB@`!$KNG&``!N?)0@4%@H'BGA@`?[#D`!\!EN>BP&;EA0#'L.0`'H&6Y
MZ+`3N6%`D;D$`$NY!``IP.7__^8B4+"@>.MO\-``!`?^I_0``>PY``;`9>PV
M__M`94%P,$#LDP`&P&7LE__S0&72/Y``,`"Y!``JI[K_P+D4`+O`Y?__]$"Y
M!``WI_3_Q0<'ZX_P0``DN00`HN.0,"@`!..`,#``!.PI.K\]5>P2``$`V+D4
M`")!(C`XDH`@`./P_V#_<;D4`"&Y!`"S04(P..P<`%DX?J<H`$"G60``N?D0
M$KD$`"2Y%@`QITD``*@D``"G%/_^N00`*\#E___T`]<WL#BP.$*`L'-"D+!W
MZQ@`&``,0A"P<.L8`!``#$(0L''K&``(``Q"$+!RZQD`&``,0A"P=.L9`!``
M#$(0L'7K&0`(``Q"$+!VN00`*\#E___SV=(#H`"P!+D$`"O2`Z`$L`S2`Z`(
ML!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__Y2*G*``XIUD``+GY$!*Y!``DN18`
M,:=)``"H)```IQ3__J?T_[('!\08```KG.P8`!K_?.N_\%@`)./P_V#_<<"P
M```KD`WAX["_^/]QXQ"P```$[!;_^?]\Z[_P^``$!_X'_@<'!P?K[_!P`"3C
M\/]@_W'K[_$0``0'_@<'!P?K[_!P`"2Y!``/I_O_8.,`\```),#E___G`NOO
M\1``!`?^+W1M<```+@!005)?5$U01$E2``!414U01$E2`%1-4`!54T52``!5
M4T523D%-10``+BX``"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S`%!!4E]4
M14U0``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),
M-4]05```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``
M4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X``%!!4E]#3$5!3CT``#$`3$1?3$E"4D%265]0051(`%-94U1%30``
M)3`R>```<&%R+0``)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP
M87(``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,``$%21U8``!@`<&5R;```4$%2.CI086-K97(Z.E9%4E-)3TX``#$N
M,#4P`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,`7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("````$;`SL```#0````&?__
MC8P```38__^1K````.S__Y)<```!*/__DJ0```%4__^3+````83__Y2$```!
MP/__E10```'P__^73````BS__Y>,```"3/__E^P```*(__^8]````L3__YC\
M```"V/__FM0```,4__^:_````RC__YPD```#3/__G:P```-X__^>'````Z3_
M_YY,```#Q/__GOP```00__^E1```!&#__ZD$```$G/__J6P```4<__^_/```
M!5C__[^L```%?/__P/P```6X````%``````!>E(``7@.`1L,#Z`!````````
M.````!S__Y"X````K@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`H(*S\[-
MS,O*R<C'Q@Z@`4(+````*````%C__Y$L````0@!&BPF,"(T'C@:/!48.T`)T
MS\[-S,L.H`$````````L````A/__D4@```"&`$:)"XH*BPF,"(T'C@:/!48.
MT`(">,_.S<S+RLD.H`$````X````M/__D:````%8`$:&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.V`,#`4K/SLW,R\K)R,?&#J`!```````L````\/__DKP```"0
M`$:*"HL)C`B-!XX&CP5&#M@#`H+/SLW,R\H.H`$````````X```!(/__DQP`
M``(R`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`(#`B3/SLW,R\K)R,?&#J`!
M```````<```!7/__E1@````\`$R.!H\%1@[``F3/S@Z@`0```#@```%\__^5
M.````%H`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[(`@),S\[-S,O*R<C'Q@Z@
M`0```````#@```&X__^57````00`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0
M0@+VS\[-S,O*R<C'Q@Z@`0```````!````'T__^6*`````8`````````.```
M`@C__Y8<```!U@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`C`P'(S\[-S,O*
MR<C'Q@Z@`0``````$````D3__Y>X````(@`````````@```"6/__E\P```$B
M``+BC@:/!48.P`)>S\X.H`$````````H```"?/__F-````&"`$R+"8P(C0>.
M!H\%1@[P`@,!;L_.S<S+#J`!`````"@```*H__^:+````&X`6HX&CP5&#L`"
M=@K/S@Z@`4@+2`Z@`<[/````````'````M3__YIP````+`!&C@:/!48.P`)>
MS\X.H`$```!(```"]/__FH````"L`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.
MP`)N"L_.S<S+RLG(Q\8.H`%&"P)FS\[-S,O*R<C'Q@Z@`0``````3````T#_
M_YKD```&0@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#HB%`@*&"L_.S<S+RLG(
MQ\8.H`%&"P,!O@K/SLW,R\K)R,?&#J`!0@L````X```#D/__H-P```.^`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.P`(#`[#/SLW,R\K)R,?&#J`!```````X
M```#S/__I&````!H`$:*"HL)C`B-!XX&CP5&#L`"`DX*S\[-S,O*#J`!1@M&
MS\[-S,O*#J`!``````!````$"/__B*P```(4`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!48.V`(#`=P*S\[-S,O*R<C'Q@Z@`4(+`````````````#@```1,__^D
M2```%=``6(8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,5L,_.S<S+RLG(Q\8.
MH`$``````"````2(__^YW````&P`2HX&CP5&#L`"`EK/S@Z@`0```````#@`
M``2L__^Z*````4X`3(8.APV(#(D+B@J+"8P(C0>.!H\%7@[``@+B"L_.S<S+
MRLG(Q\8.H`%""P```#0```3H__^[/````18`1H@,B0N*"HL)C`B-!XX&CP5N
M#L`"`K@*S\[-S,O*R<@.H`%&"P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#__________P``````````____
M______\````````````````````!`````````P$``````````0````````,,
M``````````\````````$-@`````````,````````&'``````````#0``````
M`%3X`````&___O4````````"&``````````%````````#"``````````!@``
M``````+P``````````H````````$5``````````+`````````!@`````````
M%0````````````````````,```````"MF``````````"````````!8@`````
M````%``````````'`````````!<````````2Z``````````'````````$'@`
M````````"`````````)P``````````D`````````&``````````8````````
M````````;___^P`````(```!`````&____D`````````#@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````J_@`````````````````
M````````````&,8````````8Y@```````!D&````````&28````````91@``
M`````!EF````````&88````````9I@```````!G&````````&>8````````:
M!@```````!HF````````&D8````````:9@```````!J&````````&J8`````
M```:Q@```````!KF````````&P8````````;)@```````!M&````````&V8`
M```````;A@```````!NF````````&\8````````;Y@```````!P&````````
M'"8````````<1@```````!QF````````'(8````````<I@```````!S&````
M````'.8````````=!@```````!TF````````'48````````=9@```````!V&
M````````':8````````=Q@```````!WF````````'@8````````>)@``````
M`!Y&````````'F8````````>A@```````!ZF````````'L8````````>Y@``
M`````!\&````````'R8````````?1@```````!]F````````'X8````````?
MI@```````!_&````````'^8````````@!@```````"`8````````````````
M`````````````%3X`````````````````````````````!AP````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!5&@```````%4@````
M``````````````!5(@```````%4F````````52X```````!5F@```````%4V
M``````````````````!5.@```````%5```````````````````!7^D=#0SH@
M*$%L<&EN92`Q,"XR+C%?<')E,"D@,3`N,BXQ(#(P,C`Q,3$S`$=#0SH@*$%L
M<&EN92`Q,"XR+C%?<')E,2D@,3`N,BXQ(#(P,C`Q,C`S```N<VAS=')T86(`
M+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M``````````(````````"``````````(``````````!@`````````````````
M```!```````````````3;___]@`````````"`````````A@````````"&```
M``````#8`````P``````````````"```````````````'0````L`````````
M`@````````+P`````````O`````````),`````0````"``````````@`````
M````&````"4````#``````````(````````,(`````````P@````````!%0`
M```````````````````!```````````````M````!``````````"````````
M$'@````````0>`````````)P`````P``````````````"``````````8````
M-P````0`````````0@```````!+H````````$N@````````%B`````,````1
M``````````@`````````&````$$````!``````````8````````8<```````
M`!AP`````````"@````````````````````"```````````````\`````0``
M```````&````````&)@````````8F`````````>`````````````````````
M!``````````@````1P````$`````````!@```````"`8````````(!@`````
M```TX`````````````````````@``````````````$T````!``````````8`
M``````!4^````````%3X`````````"(````````````````````"````````
M``````!3`````0`````````"````````51H```````!5&@```````#UR````
M`````````````````@``````````````6P````$``````````@```````)*,
M````````DHP`````````U`````````````````````0``````````````&D`
M```!``````````(```````"38````````)-@````````!2``````````````
M```````(``````````````!S`````0`````````#````````J]@```````";
MV``````````0````````````````````"```````````````>@````$`````
M`````P```````*OH````````F^@`````````$`````````````````````@`
M`````````````($````&``````````,```````"K^````````)OX````````
M`:`````$```````````````(`````````!````"*`````0`````````#````
M````K9@```````"=F`````````)H````````````````````"``````````(
M````CP````$``````````P```````+``````````H```````````>```````
M``````````````@``````````````)4````(``````````,```````"P>```
M`````*!X````````$&`````````````````````(``````````````":````
M`0`````````P``````````````````"@>`````````!4````````````````
M`````0`````````!`````0````,`````````````````````````````H,P`
?````````HP````````````````````$`````````````
